require "regex_data/version"

module RegexData
  def self.email? data
    if data =~ /^(?:(?:[\w`~!#$%^&*\-=+;:{}'|,?\/]+(?:(?:\.(?:"(?:\\?[\w`~!#$%^&*\-=+;:{}'|,?\/\.()<>\[\] @]|\\"|\\\\)*"|[\w`~!#$%^&*\-=+;:{}'|,?\/]+))*\.[\w`~!#$%^&*\-=+;:{}'|,?\/]+)?)|(?:"(?:\\?[\w`~!#$%^&*\-=+;:{}'|,?\/\.()<>\[\] @]|\\"|\\\\)+"))@(?:[a-zA-Z\d\-]+(?:\.[a-zA-Z\d\-]+)*|\[\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}\])$/
      return true
    else
      return false
    end
  end

  def self.strong_password? data
    if data =~ /^(?!.*(.)\1{1})(?=(.*[\d]){2,})(?=(.*[a-z]){2,})(?=(.*[A-Z]){2,})(?=(.*[@#$%!]){2,})(?:[\da-zA-Z@#$%!]){15,100}$/
      return true
    else
      return false
    end
  end

  def self.color_code? data
    if data =~ /rgb\((?:([0-9]{1,2}|1[0-9]{1,2}|2[0-4][0-9]|25[0-5]), ?)(?:([0-9]{1,2}|1[0-9]{1,2}|2[0-4][0-9]|25[0-5]), ?)(?:([0-9]{1,2}|1[0-9]{1,2}|2[0-4][0-9]|25[0-5]))\)/
      return true
    else
      return false
    end
  end

  def self.date? data
    if data =~ /^([0]?[1-9]|[1|2][0-9]|[3][0|1])[\.|\-]([0]?[1-9]|[1][0-2])[\.|\-]([0-9]{4}|[0-9]{2})$/
      return true
    else
      return false
    end
  end

  def self.ban_word data, *args
    ban = args.join("|")
    return data.gsub!(/(#{ban})/, '****')
  end

  def self.remove_extra_space data
    data.gsub!(/\s+/, ' ')
    return data.gsub(/^\s+|\s+$/, '')
  end

  def self.remove_all_spaces data
    return  data.gsub(/\s+/, '')
  end

  def self.min_length data, min
    data.length >= min ? true : false
  end

  def self.max_length data, max
    data.length <= max ? true : false
  end

  def self.remove_empty_line data
    return data.gsub(/[\n]+/, "\n")
  end

  def self.remove_html_tag data
    return data.gsub(/(<(\/?[^\>]+)>)/, "")
  end

  def self.ip_address_v4? data
    if data =~ /\b(?:(?:2(?:[0-4][0-9]|5[0-5])|[0-1]?[0-9]?[0-9])\.){3}(?:(?:2([0-4][0-9]|5[0-5])|[0-1]?[0-9]?[0-9]))\b/
      return true
    else
      return false
    end
  end

  def self.url? data
    if data =~ /((?:https\:\/\/)|(?:http\:\/\/)|(?:www\.))?([a-zA-Z0-9\-\.]+\.[a-zA-Z]{2,3}(?:\??)[a-zA-Z0-9\-\._\?\,\'\/\\\+&%\$#\=~]+)/
      return true
    else
      return false
    end
  end
end
